@@ -144,15 +144,20 @@ typedef struct {
 typedef struct {
   GSList *list;
   GSList *list_widgets;
+  GSList *list_values;
+  GSList *column_values;
   gchar *dialog_text;
   gchar *separator;
   gchar *date_format;
+//  gchar *hide_column;
+  gboolean show_header;
 } ZenityFormsData;
 
 typedef enum {
   ZENITY_FORMS_ENTRY,
   ZENITY_FORMS_PASSWORD,
-  ZENITY_FORMS_CALENDAR
+  ZENITY_FORMS_CALENDAR,
+  ZENITY_FORMS_LIST
 } ZenityFormsType;
 
 typedef struct {
